/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999-2007 Bull S.A.S.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: TransactionService.java 10454 2007-05-24 11:39:18Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.jtm;

import javax.transaction.NotSupportedException;
import javax.transaction.SystemException;
import javax.transaction.UserTransaction;
import javax.transaction.xa.Xid;

import org.objectweb.jotm.Current;
import org.objectweb.jotm.TransactionFactory;
import org.objectweb.jonas.service.Service;
import org.objectweb.transaction.jta.TransactionManager;

/**
 * Transaction Service interface.
 */
public interface TransactionService extends Service {

    /**
     * Gets the Current object.
     */
    Current getCurrent();

    /**
     * Gets the TransactionManager.
     */
    TransactionManager getTransactionManager();

    /**
     * @return Returns the {@link UserTransaction} object.
     */
    UserTransaction getUserTransaction();

    /**
     * @return Returns the {@link TransactionFactory} object (JTM factory).
     */
    TransactionFactory getTransactionFactory();

    /**
     * Sets the default transaction timeout.
     * @param t default transaction timeout.
     */
    void setTimeout(int t);

    /**
     * Attach the current calling {@link Thread} to the given {@link Xid}.
     * @param xid Transaction id.
     * @param timeout Transaction timeout.
     * @throws SystemException if the TM cannot attach the given {@link Xid}.
     * @throws NotSupportedException if the TM cannot attach the given {@link Xid}.
     */
    void attachTransaction(Xid xid, long timeout) throws NotSupportedException, SystemException;

    /**
     * Detach the current {@link Thread} of the running Transaction.
     */
    void detachTransaction();
}

