/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2003-2005 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $$Id: DaemonProxyClusterAction.java 10907 2007-07-10 18:51:35Z eyindanga $$
 * --------------------------------------------------------------------------
 */
package org.objectweb.jonas.webapp.jonasadmin.cd;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Hashtable;
import java.util.Iterator;

import javax.management.ObjectName;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.objectweb.jonas.webapp.jonasadmin.monitoring.DaemonProxyClusterForm;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.objectweb.jonas.webapp.jonasadmin.JonasManagementRepr;
import org.objectweb.jonas.jmx.oname.JonasObjectName;
import org.objectweb.jonas.management.cluster.BaseCluster;
import org.objectweb.jonas.management.j2eemanagement.J2EEDomain;
import org.objectweb.jonas.management.monitoring.DomainMonitor;
import org.objectweb.jonas.management.monitoring.proxy.server.ServerProxy;
import org.objectweb.jonas.webapp.jonasadmin.JonasBaseAction;
import org.objectweb.jonas.webapp.jonasadmin.WhereAreYou;
import org.objectweb.jonas.webapp.jonasadmin.common.BeanComparator;
import org.objectweb.jonas.webapp.jonasadmin.domain.ServerItem;

public class DaemonProxyClusterAction extends JonasBaseAction {

    @SuppressWarnings("unchecked")
    public ActionForward executeAction(ActionMapping p_Mapping,
            ActionForm p_Form, HttpServletRequest p_Request,
            HttpServletResponse p_Response) throws IOException,
            ServletException {
        String isNotMonitoringStr=null;
        String sDomainName = m_WhereAreYou.getCurrentDomainName();
        String serverName = m_WhereAreYou.getAdminJonasServerName();
        DaemonProxyClusterForm oForm = (DaemonProxyClusterForm) p_Form;
        String name = null;
        try {

            name=p_Request.getParameter("node");
            isNotMonitoringStr="true";
            ObjectName on = JonasObjectName.clusterDaemonProxy(sDomainName,name);
            m_WhereAreYou.setCurrentClusterDaemon(on);
            m_WhereAreYou.setCurrentClusterDaemonName(name);
            //the array list to contain the server list
            ArrayList al = null;
            //are all the servers already started ?
            boolean allStarted = true;
            //let know if no server is running
            boolean noneStarted = true;
            oForm.setName((String) JonasManagementRepr.getAttribute(on,
                    "Name", serverName));
            oForm.setState((String) JonasManagementRepr.getAttribute(on,
                    "State", serverName));
            //if the jmx url is null that means a problem has happened while getting this attribute
            String jmxUrl = (String) JonasManagementRepr.getAttribute(on,
                    "JmxUrl", serverName);
            if (jmxUrl != null ) {
                //Go on only when it's necessary
                oForm.setJmxUrl((String) JonasManagementRepr.getAttribute(on,
                        "JmxUrl", serverName));
                oForm.setConServer((ArrayList) JonasManagementRepr.getAttribute(on,
                        "ControlledServersNames", serverName));
                ArrayList<String> srvList=oForm.getConServer();

                DomainMonitor dm = J2EEDomain.getInstance().getDomainMonitor();
                al = new ArrayList();
                //are all the servers already started ?
                allStarted=true;
                //let know if no server is running
                noneStarted=true;
//				getting requested cluster daemon Administrated Jonas servers...
                for (Iterator it = dm.getServerList().iterator(); it.hasNext();) {
                    ServerProxy proxy = (ServerProxy) it.next();
                    if (srvList.contains(proxy.getName())&&(proxy.getClusterDaemonName() == null)) {
                        //if the server is in the clusterd.xml but not in the domain.xml
                        proxy.setClusterdaemon(dm.findClusterDaemonProxy(name));
                    }
                    if(proxy.getClusterDaemonName()!=null) {

                        if(proxy.getClusterDaemonName().equals(name)) {
                            ObjectName myOn = ObjectName.getInstance(proxy.getJ2eeObjectName());
                            al.add(new ServerItem(myOn, proxy.getState(), proxy.getClusterDaemonName(),srvList.contains(proxy.getName())));
                            //no server is started we want to disable the startAll operation in the jsp
                            if (noneStarted) {
                                noneStarted=!proxy.getState().equals("RUNNING");
                            }
                            allStarted=(allStarted && proxy.getState().equals("RUNNING"));
                        }
                    }
                }
                Collections.sort(al, new BeanComparator(new String[] {"name"}));
            }
            //if a problem has happened while getting jmxUrl then :
            //forward the response to with default values
            p_Request.setAttribute("listServers", al);
            p_Request.setAttribute("allStarted", allStarted);
            p_Request.setAttribute("noneStarted", noneStarted);
            p_Request.setAttribute("isNotMonitoring", isNotMonitoringStr);
        } catch (Throwable t) {
            addGlobalError(t);
            saveErrors(p_Request, m_Errors);
            return (p_Mapping.findForward("Global Error"));
        }
        // Forward to the jsp.
        return (p_Mapping.findForward("DaemonProxyCluster"));
    }
}
