/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2006-2007 Bull S.A.S
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ClusterDaemonProxyMBean.java 10840 2007-07-04 17:59:52Z eyindanga $
 * --------------------------------------------------------------------------
 */
package org.objectweb.jonas.management.monitoring.proxy.clusterd;

import java.util.ArrayList;
import java.util.Hashtable;



/**
 * Implements MBean interface for cluster daemon proxy MBeans. A cluster daemon proxy MBean represents
 * cluster daemon in the domain on the master server's MBean server.
 * @author Adriana Danes
 */
/**
 * @author eyindanga
 *
 */
public interface ClusterDaemonProxyMBean {
    /**
     *
     * @return the clsuter daemon name
     */
    public String getName();

    /**
     *
     * @param name
     */
    public void setName(String name);
//	this method will be used to save Cd config in the xml file
    public void save(String name);
    /**
     *
     * @param serverName
     * @param otherParams
     * @return
     */
    public boolean startServer(String serverName, String otherParams);
    /**
     *
     * @param serverName
     * @param otherParams
     * @return
     */
    public boolean stopServer(String serverName, String otherParams);
    /**
     *
     * @param otherParams
     */
    public void startAllServers(String otherParams);
    /**
     *
     * @param otherParams
     */
    public void stopAllServers(String otherParams);
    /**
     *
     * @param name
     * @return
     */
    public int pingJOnAS(String name);
    /**
     *
     *Reload clusterd configuration
     */
    public void reloadConfiguration();
    /**
     *
     * @return
     */
    public String getHostName();
    /**
     * @return the server's state as known by the proxy
     */
    public String getState();
    /**
     *
     * @return list of controlled servers.
     */
    public ArrayList getControlledServersNames();
    /**
     *
     * @return the clusterd JmxUrl
     */
    public String getJmxUrl();

    /**
     *
     * @return
     */
    public Hashtable<String, String> dynamicRemoteHostInfos();

    /**
     * @return the operatingSystemAvailableProcessors
     */
    public String getOperatingSystemAvailableProcessors();

    /**
     * @return the operatingSystemName
     */
    public String getOperatingSystemName();

    /**
     * @return the operatingSystemVersion
     */
    public String getOperatingSystemVersion();

    /**
     * @return the runTimeSpecVendor
     */
    public String getRunTimeSpecVendor();

    /**
     * @return the runTimeSpecVersion
     */
    public String getRunTimeSpecVersion();

    /**
     * @return the runTimeVmName
     */
    public String getRunTimeVmName();

    /**
     * @return the runTimeVmVendor
     */
    public String getRunTimeVmVendor();

    /**
     * @return the runTimeVmVersion
     */
    public String getRunTimeVmVersion();



}